GradLogLikLogParm_02: Calculates the gradient of the function of the transformed...

View source: R/GradLogLikLogParm_02.R

GradLogLikLogParm_02R Documentation

Calculates the gradient of the function of the transformed parameter

Description

Calculates the gradient of the function of the transformed parameter

Usage

GradLogLikLogParm_02(
  adj_positions,
  logParm,
  matList,
  dataset,
  interaction_effects = list(),
  joint_estimation = FALSE
)

Arguments

adj_positions

positions of the spatial effect (if embedded)

logParm

the transformed parameter

matList

the list of matrices (pairwise + spatial)

dataset

an n (observations) x d (dimensions) matrix

interaction_effects

list of interaction effects (vectors of names)

joint_estimation

estimates everything jointly if TRUE, uses a 2 step procedure if FALSE

Value

the gradient of the function of the transformed parameter


scov documentation built on March 18, 2026, 5:08 p.m.