View source: R/GradLogLikParm_02.R
| GradLogLikParm_02 | R Documentation |
Calculates the gradient of the loglikelihood or the gradient of Sigma
GradLogLikParm_02(
adj_positions,
parm,
matList,
dataset,
interaction_effects = list(),
return_Sigma_der = FALSE
)
adj_positions |
positions of the spatial effect (if embedded) |
parm |
the parameter |
matList |
the list of matrices (pairwise + spatial) |
dataset |
an n (observations) x d (dimensions) matrix |
interaction_effects |
list of interaction effects (vectors of names) |
return_Sigma_der |
returns the gradient of Sigma if TRUE |
the gradient of the loglikelihood or the gradient of Sigma
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.