calc_Dmat: Calculates the matrix D used in the quadratic minimization...

View source: R/calc_Dmat.R

calc_DmatR Documentation

Calculates the matrix D used in the quadratic minimization problem

Description

Calculates the matrix D used in the quadratic minimization problem

Usage

calc_Dmat(matList_full)

Arguments

matList_full

combined list of pairwise and spatial matrices

Value

the matrix D


scov documentation built on March 18, 2026, 5:08 p.m.