calc_dvec: Calculates the vector d used in the quadratic minimization...

View source: R/calc_dvec.R

calc_dvecR Documentation

Calculates the vector d used in the quadratic minimization problem

Description

Calculates the vector d used in the quadratic minimization problem

Usage

calc_dvec(S, matList_full)

Arguments

S

the Pearson correlation matrix

matList_full

combined list of pairwise and spatial matrices

Value

the vector d


scov documentation built on March 18, 2026, 5:08 p.m.