calc_tilde_G_inv_partial_beta: Calculates the derivative of the inverse of G (the CAR model...

View source: R/calc_tilde_G_inv_partial_beta.R

calc_tilde_G_inv_partial_betaR Documentation

Calculates the derivative of the inverse of G (the CAR model matrix)

Description

Calculates the derivative of the inverse of G (the CAR model matrix)

Usage

calc_tilde_G_inv_partial_beta(M, A, beta)

Arguments

M

matrix used in the definition of the CAR model

A

matrix used in the definition of the CAR model

beta

autocorrelation parameter of the CAR model

Value

the derivative of the inverse of G (the CAR model matrix)


scov documentation built on March 18, 2026, 5:08 p.m.