View source: R/correlation_matrix.R
| correlation_matrix | R Documentation |
Estimates the correlation matrix of the dataset
correlation_matrix(dataset, mean_estim, sd_estim)
dataset |
n x d matrix (n = number of observations, d = dimension) |
mean_estim |
estimate of the mean vector of the dataset |
sd_estim |
estimate of the standard deviation vector of the dataset |
an estimate of the correlation matrix
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.