forward_transform_param: Transforms the parameter using a logit and inverse softmax

View source: R/forward_transform_param.R

forward_transform_paramR Documentation

Transforms the parameter using a logit and inverse softmax

Description

Transforms the parameter using a logit and inverse softmax

Usage

forward_transform_param(param)

Arguments

param

the parameter

Value

the transformed parameter


scov documentation built on March 18, 2026, 5:08 p.m.