frob_scalar_prod: Calculates the Frobenius inner product between to square...

View source: R/frob_scalar_prod.R

frob_scalar_prodR Documentation

Calculates the Frobenius inner product between to square matrices

Description

Calculates the Frobenius inner product between to square matrices

Usage

frob_scalar_prod(A, B)

Arguments

A

a square matrix

B

a square matrix

Value

the Frobenius inner product


scov documentation built on March 18, 2026, 5:08 p.m.