get_M_A: Computes the matrices needed for the spatial effect

View source: R/get_M_A.R

get_M_AR Documentation

Computes the matrices needed for the spatial effect

Description

Computes the matrices needed for the spatial effect

Usage

get_M_A(adj_matrix)

Arguments

adj_matrix

the adjacency matrix of the spatial effect

Value

a list containing Ml and Al, which are used to compute the correlation matrix for the spatial effect


scov documentation built on March 18, 2026, 5:08 p.m.