mat_support_distance: Computes a measure of distance between the support of two...

View source: R/mat_support_distance.R

mat_support_distanceR Documentation

Computes a measure of distance between the support of two matrices

Description

Computes a measure of distance between the support of two matrices

Usage

mat_support_distance(mat1, mat2)

Arguments

mat1

a square matrix

mat2

a square matrix

Value

a measure of distance between the support of two matrices


scov documentation built on March 18, 2026, 5:08 p.m.