| sce | R Documentation |
This function computes the SCE estimator for large covariances in the presence of pairwise and spatial covariates from Metodiev et al. (2024).
sce(
pairwise_covariate_matrices,
adj_matrix,
dataset,
mean_estim = NULL,
sd_estim = NULL,
grid_size = 100,
parallelize = TRUE,
ncores = 8,
adj_positions = 1:nrow(adj_matrix),
interaction_effects = list(),
init = NULL,
verbose = TRUE,
joint_estimation = FALSE
)
pairwise_covariate_matrices |
named list of square matrices |
adj_matrix |
adjacency matrix of the spatial covariate |
dataset |
the dataset given in matrix form |
mean_estim |
mean vector estimate |
sd_estim |
standard deviation vector estimate |
grid_size |
grid-size for spatial effect |
parallelize |
uses parallel-processing if TRUE |
ncores |
number of cores for the parallelization |
adj_positions |
positions within the adjacency matrix |
interaction_effects |
list of interaction effects |
init |
the initialization parameter vector |
verbose |
prints progress if TRUE |
joint_estimation |
estimates everything jointly if TRUE, uses a 2 step procedure if FALSE |
Returns a named list with the following elements:
parm, estimated parameters of pairwise, spatial effects, average_effects, average effects of the covariates, corrmat_estim, estimator of the correlation matrix, covmat_estim, estimator of the covariance matrix, bic, the Bayesian information criterion (BIC)
Metodiev, M., Perrot-Dockès, M., Ouadah, S., Fosdick, B. K., Robin, S., Latouche, P., & Raftery, A. E. (2024). A Structured Estimator for large Covariance Matrices in the Presence of Pairwise and Spatial Covariates. arXiv preprint arXiv:2411.04520.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.