test_func: Bootstrap simulations for the WSCE

View source: R/test_func.R

test_funcR Documentation

Bootstrap simulations for the WSCE

Description

This function is computed multiple times as a bootstrap sample

Usage

test_func(
  s,
  num_bootstrap_iters,
  seed,
  dimension,
  num_observations,
  pearson_mat,
  dataset,
  parm,
  pairwise_covariate_matrices,
  adj_matrix,
  grid_size,
  adj_positions,
  interaction_effects,
  verbose,
  joint_estimation
)

Arguments

s

label of the sample

num_bootstrap_iters

number of iterations

seed

the seed

dimension

the dimension of the data

num_observations

size of the data

pearson_mat

the pearson correlation matrix

dataset

the dataset

parm

the parameter estimated from the sce

pairwise_covariate_matrices

the list of covariate matrices

adj_matrix

adjacency matrix of the spatial effect

grid_size

size of the grid for the spatial effect

adj_positions

positions within the adjacency matrix

interaction_effects

list of interaction effects

verbose

prints progress if TRUE

joint_estimation

estimates everything jointly if TRUE, uses a 2 step procedure if FALSE

Value

Returns an array containing the simulated value of the SCE and the Pearson correlation matrix


scov documentation built on March 18, 2026, 5:08 p.m.