| tilde_G_inv | R Documentation |
Computes the inverse of the correlation matrix of the CAR model
tilde_G_inv(
M = NULL,
A = NULL,
beta,
U_full = NULL,
solve_U_full = NULL,
solve_M_no_islands = NULL,
eigen_real = NULL,
return_U_D_M = FALSE
)
M |
used to define the CAR correlation matrix |
A |
used to define the CAR correlation matrix |
beta |
autocorrelation parameter of the CAR model |
U_full |
(optional) can be used to fasten computation |
solve_U_full |
(optional) can be used to fasten computation |
solve_M_no_islands |
(optional) can be used to fasten computation |
eigen_real |
(optional) can be used to fasten computation |
return_U_D_M |
(optoinal) can be used to fasten computation |
the inverse of the correlation matrix of the CAR model
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.