to_positive_definite: Maps the pairwise covariates to symmetric, positive definite...

View source: R/to_positive_definite.R

to_positive_definiteR Documentation

Maps the pairwise covariates to symmetric, positive definite matrices

Description

Maps the pairwise covariates to symmetric, positive definite matrices

Usage

to_positive_definite(pairwise_covariate_matrices, eig.tol = 1e-06)

Arguments

pairwise_covariate_matrices

list of pairwise covariate matrices

eig.tol

treat EV a as negative if (a / largest eigenvalue) <= eig.tol

Value

list of pairwise covariate matrices


scov documentation built on March 18, 2026, 5:08 p.m.