View source: R/GradLogLikLogParm_02.R
| GradLogLikLogParm_02 | R Documentation |
Calculates the gradient of the function of the transformed parameter
GradLogLikLogParm_02(
adj_positions,
logParm,
matList,
dataset,
interaction_effects = list(),
joint_estimation = FALSE
)
adj_positions |
positions of the spatial effect (if embedded) |
logParm |
the transformed parameter |
matList |
the list of matrices (pairwise + spatial) |
dataset |
an n (observations) x d (dimensions) matrix |
interaction_effects |
list of interaction effects (vectors of names) |
joint_estimation |
estimates everything jointly if TRUE, uses a 2 step procedure if FALSE |
the gradient of the function of the transformed parameter
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.