Learn R Programming

scov (version 0.1.2)

calc_Dmat: Calculates the matrix D used in the quadratic minimization problem

Description

Calculates the matrix D used in the quadratic minimization problem

Usage

calc_Dmat(matList_full)

Value

the matrix D

Arguments

matList_full

combined list of pairwise and spatial matrices