calc_tilde_G_inv_partial_beta: Calculates the derivative of the inverse of G (the CAR model matrix)
Description
Calculates the derivative of the inverse of G (the CAR model matrix)
Usage
calc_tilde_G_inv_partial_beta(M, A, beta)
Value
the derivative of the inverse of G (the CAR model matrix)
Arguments
- M
matrix used in the definition of the CAR model
- A
matrix used in the definition of the CAR model
- beta
autocorrelation parameter of the CAR model