Learn R Programming

scov (version 0.1.2)

frob_scalar_prod: Calculates the Frobenius inner product between to square matrices

Description

Calculates the Frobenius inner product between to square matrices

Usage

frob_scalar_prod(A, B)

Value

the Frobenius inner product

Arguments

A

a square matrix

B

a square matrix