| get_M_A | R Documentation |
Computes the matrices needed for the spatial effect
get_M_A(adj_matrix)
adj_matrix |
the adjacency matrix of the spatial effect |
a list containing Ml and Al, which are used to compute the correlation matrix for the spatial effect
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.