View source: R/mat_support_distance.R
| mat_support_distance | R Documentation |
Computes a measure of distance between the support of two matrices
mat_support_distance(mat1, mat2)
mat1 |
a square matrix |
mat2 |
a square matrix |
a measure of distance between the support of two matrices
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.