Learn R Programming

scov (version 0.1.2)

mat_support_distance: Computes a measure of distance between the support of two matrices

Description

Computes a measure of distance between the support of two matrices

Usage

mat_support_distance(mat1, mat2)

Value

a measure of distance between the support of two matrices

Arguments

mat1

a square matrix

mat2

a square matrix