Learn R Programming

scov (version 0.1.2)

tilde_G_inv: Computes the inverse of the correlation matrix of the CAR model

Description

Computes the inverse of the correlation matrix of the CAR model

Usage

tilde_G_inv(
  M = NULL,
  A = NULL,
  beta,
  U_full = NULL,
  solve_U_full = NULL,
  solve_M_no_islands = NULL,
  eigen_real = NULL,
  return_U_D_M = FALSE
)

Value

the inverse of the correlation matrix of the CAR model

Arguments

M

used to define the CAR correlation matrix

A

used to define the CAR correlation matrix

beta

autocorrelation parameter of the CAR model

U_full

(optional) can be used to fasten computation

solve_U_full

(optional) can be used to fasten computation

solve_M_no_islands

(optional) can be used to fasten computation

eigen_real

(optional) can be used to fasten computation

return_U_D_M

(optoinal) can be used to fasten computation