Computes the inverse of the correlation matrix of the CAR model
tilde_G_inv(
M = NULL,
A = NULL,
beta,
U_full = NULL,
solve_U_full = NULL,
solve_M_no_islands = NULL,
eigen_real = NULL,
return_U_D_M = FALSE
)the inverse of the correlation matrix of the CAR model
used to define the CAR correlation matrix
used to define the CAR correlation matrix
autocorrelation parameter of the CAR model
(optional) can be used to fasten computation
(optional) can be used to fasten computation
(optional) can be used to fasten computation
(optional) can be used to fasten computation
(optoinal) can be used to fasten computation