Learn R Programming

scov (version 0.1.2)

to_positive_definite: Maps the pairwise covariates to symmetric, positive definite matrices

Description

Maps the pairwise covariates to symmetric, positive definite matrices

Usage

to_positive_definite(pairwise_covariate_matrices, eig.tol = 1e-06)

Value

list of pairwise covariate matrices

Arguments

pairwise_covariate_matrices

list of pairwise covariate matrices

eig.tol

treat EV a as negative if (a / largest eigenvalue) <= eig.tol